@@ -35,8 +35,8 @@
 #' to start training.
 #' @param script_params A named list of the command-line arguments to pass to
 #' the training script specified in `entry_script`.
-#' @param cran_packages A character vector of CRAN packages to be installed.
-#' @param github_packages A character vector of GitHub packages to be installed.
+#' @param cran_packages A list of `cran_package` objects to be installed.
+#' @param github_packages A list of `github_package` objects to be installed.
 #' @param custom_url_packages A character vector of packages to be installed
 #' from local directory or custom URL.
 #' @param custom_docker_image A string of the name of the Docker image from
@@ -71,8 +71,20 @@
 #' objects to use as input.
 #' @return The `Estimator` object.
 #' @export
+#' @section Examples:
+#' ```
+#' r_env <- r_environment(name = "r-env",
+#'                        cran_packages = list(cran_package("dplyr"),
+#'                                             cran_package("ggplot2")))
+#' est <- estimator(source_directory = ".",
+#'                  entry_script = "train.R",
+#'                  compute_target = compute_target,
+#'                  environment = r_env)
+#' ```
 #' @seealso
-#' `r_environment()`, `container_registry()`, `submit_experiment()`
+#' [r_environment()], [container_registry()], [submit_experiment()],
+#' [dataset_consumption_config()], [cran_package()]
+#'
 #' @md
 estimator <- function(source_directory,
                       compute_target = NULL,
@@ -93,6 +105,16 @@ estimator <- function(source_directory,
                       inputs = NULL) {
 
   if (is.null(environment)) {
+    if (!is.null(list(cran_packages, github_packages, custom_url_packages,
+                      custom_docker_image, image_registry_details,
+                      environment_variables, shm_size)) || use_gpu) {
+      warning(paste0("cran_packages, github_packages, custom_url_packages, ",
+                     "custom_docker_image, image_registry_details, use_gpu, ",
+                     "environment_variables, and shm_size parameters will be",
+                     " deprecated. Please create an environment object with ",
+                     "them using r_environment() and pass the environment",
+                     " object to the estimator()."))
+    }
     environment <- r_environment(
       name = "estimatorenv",
       environment_variables = environment_variables,
