@@ -19,6 +19,9 @@
 #'   sensitive information that's needed by the workspace.
 #' @param name A string of the new workspace name. Workspace name has to be
 #' between 2 and 32 characters of letters and numbers.
+#' @param auth The `ServicePrincipalAuthentication` or `InteractiveLoginAuthentication`
+#' object. For more details refer to https://aka.ms/aml-notebook-auth. If NULL,
+#' the default Azure CLI credentials will be used or the API will prompt for credentials.
 #' @param subscription_id A string of the subscription ID of the containing
 #' subscription for the new workspace. The parameter is required if the user has
 #' access to more than one subscription.
@@ -45,6 +48,18 @@
 #' Azure resource ID format. The container registry will be used by the
 #' workspace to pull and push both experimentation and webservices images. If
 #' `NULL` a new container registry will be created.
+#' @param cmk_keyvault A string representing the key vault containing the customer
+#' managed key in the Azure resource ID format:
+#' '/subscriptions//resourcegroups//providers/microsoft.keyvault/vaults/'. For
+#' example: '/subscriptions/d139f240-94e6-4175-87a7-954b9d27db16/resourcegroups/myresourcegroup/providers/microsoft.keyvault/vaults/mykeyvault'.
+#' @param resource_cmk_uri The key URI of the customer managed key to encrypt the data at rest.
+#' The URI format is: 'https://<keyvault-dns-name>/keys/<key-name>/<key-version>'.
+#' For example, 'https://mykeyvault.vault.azure.net/keys/mykey/bc5dce6d01df49w2na7ffb11a2ee008b'.
+#' Refer to https://docs.microsoft.com/azure-stack/user/azure-stack-key-vault-manage-portal for steps on how
+#' to create a key and get its URI.
+#' @param hbi_workspace Specifies whether the customer data is of High Business
+#' Impact(HBI), i.e., contains sensitive business information. The default value
+#' is FALSE. When set to TRUE, downstream services will selectively disable logging.
 #' @param exist_ok If `TRUE` the method will not fail if the workspace already
 #' exists.
 #' @param show_output If `TRUE` the method will print out incremental progress
@@ -53,22 +68,22 @@
 #' "enterprise" edition.
 #' @return The `Workspace` object.
 #' @export
-#' @examples
-#' # This example requires only minimal specification, and all dependent
-#' # resources as well as the resource group will be created automatically.
-#' \dontrun{
+#' @section Examples:
+#' This example requires only minimal specification, and all dependent
+#' resources as well as the resource group will be created automatically.
+#' ```
 #' ws <- create_workspace(name = 'myworkspace',
 #'                        subscription_id = '<azure-subscription-id>',
 #'                        resource_group = 'myresourcegroup',
 #'                        location = 'eastus2')
-#' }
+#' ```
 #'
-#' # This example shows how to reuse existing Azure resources by making
-#' # use of all parameters utilizing the Azure resource ID format. The specific
-#' # Azure resource IDs can be retrieved through the Azure Portal or SDK. This
-#' # assumes that the resource group, storage account, key vault, App Insights
-#' # and container registry already exist
-#' \dontrun{
+#' This example shows how to reuse existing Azure resources by making
+#' use of all parameters utilizing the Azure resource ID format. The specific
+#' Azure resource IDs can be retrieved through the Azure Portal or SDK. This
+#' assumes that the resource group, storage account, key vault, App Insights
+#' and container registry already exist.
+#' ```
 #' prefix = "subscriptions/<azure-subscription-id>/resourcegroups/myresourcegroup/providers/"
 #' ws <- create_workspace(
 #'        name = 'myworkspace',
@@ -83,10 +98,13 @@
 #'        container_registry = paste0(
 #'          prefix,
 #'          'microsoft.containerregistry/registries/mycontainerregistry'))
-#' }
+#' ```
+#' @seealso
+#' [get_workspace()] [service_principal_authentication()] [interactive_login_authentication()]
 #' @md
 create_workspace <- function(
   name,
+  auth = NULL,
   subscription_id = NULL,
   resource_group = NULL,
   location = NULL,
@@ -96,11 +114,15 @@ create_workspace <- function(
   key_vault = NULL,
   app_insights = NULL,
   container_registry = NULL,
+  cmk_keyvault = NULL,
+  resource_cmk_uri = NULL,
+  hbi_workspace = FALSE,
   exist_ok = FALSE,
   show_output = TRUE,
   sku = "basic") {
   ws <-
     azureml$core$Workspace$create(name = name,
+                                  auth = auth,
                                   subscription_id = subscription_id,
                                   resource_group = resource_group,
                                   location = location,
@@ -110,6 +132,9 @@ create_workspace <- function(
                                   key_vault = key_vault,
                                   app_insights = app_insights,
                                   container_registry = container_registry,
+                                  cmk_keyvault = cmk_keyvault,
+                                  resource_cmk_uri = resource_cmk_uri,
+                                  hbi_workspace = hbi_workspace,
                                   exist_ok = exist_ok,
                                   show_output = show_output,
                                   sku = sku)
@@ -123,16 +148,22 @@ create_workspace <- function(
 #' workspace. Throws an exception if the workpsace doesn't exist or the
 #' required fields don't lead to a uniquely identifiable workspace.
 #' @param name A string of the workspace name to get.
+#' @param auth The `ServicePrincipalAuthentication` or `InteractiveLoginAuthentication`
+#' object. For more details refer to https://aka.ms/aml-notebook-auth. If NULL,
+#' the default Azure CLI credentials will be used or the API will prompt for credentials.
 #' @param subscription_id A string of the subscription ID to use. The parameter
 #' is required if the user has access to more than one subscription.
 #' @param resource_group A string of the resource group to use. If `NULL` the
 #' method will search all resource groups in the subscription.
 #' @return The `Workspace` object.
 #' @export
+#' @seealso
+#' [create_workspace()] [service_principal_authentication()] [interactive_login_authentication()]
 #' @md
-get_workspace <- function(name, subscription_id = NULL, resource_group = NULL) {
+get_workspace <- function(name, auth = NULL, subscription_id = NULL,
+                          resource_group = NULL) {
   tryCatch({
-    azureml$core$Workspace$get(name, auth = NULL,
+    azureml$core$Workspace$get(name, auth = auth,
                                subscription_id = subscription_id,
                                resource_group = resource_group)
   },
@@ -160,6 +191,7 @@ get_workspace <- function(name, subscription_id = NULL, resource_group = NULL) {
 #' @param file_name A string that will override the config file name to
 #' search for when path is a directory path.
 #' @return The `Workspace` object.
+#' @seealso [write_workspace_config()]
 #' @export
 #' @md
 load_workspace_from_config <- function(path = NULL, file_name = NULL) {
@@ -217,11 +249,13 @@ list_workspaces <- function(subscription_id, resource_group = NULL) {
 #' same workspace in different files or projects without retyping the
 #' workspace ARM properties.
 #' @param workspace The `Workspace` object whose config has to be written down.
-#' @param path A string of the location to write the config.json file.
-#' The parameter defaults to the current working directory.
+#' @param path A string of the location to write the config.json file. The config
+#' file will be located in a directory called '.azureml'. The parameter defaults to
+#' the current working directory, so by default config.json will be located at '.azureml/'.
 #' @param file_name A string of the name to use for the config file. The
 #' parameter defaults to `'config.json'`.
 #' @return None
+#' @seealso [load_workspace_from_config()]
 #' @export
 #' @md
 write_workspace_config <- function(workspace, path = NULL, file_name = NULL) {
@@ -244,20 +278,21 @@ write_workspace_config <- function(workspace, path = NULL, file_name = NULL) {
 #' @param workspace The `Workspace` object.
 #' @return The default `Datastore` object.
 #' @export
-#' @examples
-#' # Get the default datastore for the datastore
-#' \dontrun{
+#' @section Examples:
+#' Get the default datastore for the datastore:
+#' ```
 #' ws <- load_workspace_from_config()
 #' ds <- get_default_datastore(ws)
-#' }
+#' ```
 #'
-#' # If you have not changed the default datastore for the workspace, the
-#' # following code will return the same datastore object as the above
-#' # example
-#' \dontrun{
+#' If you have not changed the default datastore for the workspace, the
+#' following code will return the same datastore object as the above
+#' example:
+#' ```
 #' ws <- load_workspace_from_config()
 #' ds <- get_datastore(ws, datastore_name = 'workspaceblobstore')
-#' }
+#' ```
+#' @seealso [set_default_datastore()]
 #' @md
 get_default_datastore <- function(workspace) {
   workspace$get_default_datastore()
@@ -273,7 +308,7 @@ get_default_datastore <- function(workspace) {
 #' @return The `Keyvault` object.
 #' @export
 #' @seealso
-#' `set_secrets()`, `get_secrets()`, `list_secrets()`, `delete_secrets()`
+#' [set_secrets()] [get_secrets()] [list_secrets()] [delete_secrets()]
 #' @md
 get_default_keyvault <- function(workspace) {
   workspace$get_default_keyvault()
@@ -284,10 +319,10 @@ get_default_keyvault <- function(workspace) {
 #' @description
 #' Returns the details of the workspace.
 #' @param workspace The `Workspace` object.
-#' @return workspace details as data frame.
+#' @return Named list of the workspace details.
 #' @export
 #' @section Details:
-#' The returned list contains the following named elements:
+#' The returned named list contains the following elements:
 #' * *id*: URI pointing to the workspace resource, containing subscription ID,
 #' resource group, and workspace name.
 #' * *name*: Workspace name.
@@ -306,8 +341,7 @@ get_default_keyvault <- function(workspace) {
 #' * *storageAccount*: Workspace storage account.
 #' @md
 get_workspace_details <- function(workspace) {
-  details <- workspace$get_details()
-  as.data.frame(details)
+  workspace$get_details()
 }
 
 #' Set the default datastore for a workspace
@@ -318,8 +352,85 @@ get_workspace_details <- function(workspace) {
 #' @param datastore_name The name of the datastore to be set as default.
 #' @return None
 #' @export
+#' @seealso [get_default_datastore()]
 #' @md
 set_default_datastore <- function(workspace, datastore_name) {
   workspace$set_default_datastore(datastore_name)
   invisible(NULL)
 }
+
+#' Manages authentication using a service principle instead of a user identity.
+#'
+#' @description
+#' Service Principal authentication is suitable for automated workflows like for CI/CD scenarios.
+#' This type of authentication decouples the authentication process from any specific user login, and
+#' allows for managed access control.
+#' @param tenant_id The string id of the active directory tenant that the service
+#' identity belongs to.
+#' @param service_principal_id The service principal ID string.
+#' @param service_principal_password The service principal password/key string.
+#' @param cloud The name of the target cloud. Can be one of "AzureCloud", "AzureChinaCloud", or
+#' "AzureUSGovernment". If no cloud is specified, "AzureCloud" is used.
+#' @return `ServicePrincipalAuthentication` object
+#' @export
+#' @section Examples:
+#' Service principal authentication involves creating an App Registration in
+#' Azure Active Directory. First, you generate a client secret, and then you grant
+#' your service principal role access to your machine learning workspace. Then,
+#' you use the `ServicePrincipalAuthentication` object to manage your authentication flow.
+#' ```
+#' svc_pr_password <- Sys.getenv("AZUREML_PASSWORD")
+#' svc_pr <- service_principal_authentication(tenant_id="my-tenant-id",
+#'                                            service_principal_id="my-application-id",
+#'                                            service_principal_password=svc_pr_password)
+#'
+#' ws <- get_workspace("<your workspace name>",
+#'                     "<your subscription ID>",
+#'                     "<your resource group>",
+#'                     auth = svc_pr)
+#' ```
+#' @seealso
+#' [get_workspace()] [interactive_login_authentication()]
+#' @md
+service_principal_authentication <- function(tenant_id, service_principal_id,
+                                             service_principal_password,
+                                             cloud = "AzureCloud") {
+  azureml$core$authentication$ServicePrincipalAuthentication(
+    tenant_id = tenant_id, service_principal_id = service_principal_id,
+    service_principal_password = service_principal_password, cloud = cloud)
+}
+
+#' Manages authentication and acquires an authorization token in interactive login workflows.
+#'
+#' @description
+#' Interactive login authentication is suitable for local experimentation on your own computer, and is the
+#' default authentication model when using Azure Machine Learning SDK.
+#' The constructor of the class will prompt you to login. The constructor then will save the credentials
+#' for any subsequent attempts. If you are already logged in with the Azure CLI or have logged-in before, the
+#' constructor will load the existing credentials without prompt.
+#' @param force Indicates whether "az login" will be run even if the old "az login" is still valid.
+#' @param tenant_id The string id of the active directory tenant that the service
+#' identity belongs to. This is can be used to specify a specific tenant when
+#' you have access to multiple tenants. If unspecified, the default tenant will be used.
+#' @param cloud The name of the target cloud. Can be one of "AzureCloud", "AzureChinaCloud", or
+#' "AzureUSGovernment". If no cloud is specified, "AzureCloud" is used.
+#' @return `InteractiveLoginAuthentication` object
+#' @export
+#' @section Examples:
+#' ```
+#' interactive_auth <- interactive_login_authentication(tenant_id="your-tenant-id")
+#'
+#' ws <- get_workspace("<your workspace name>",
+#'                     "<your subscription ID>",
+#'                     "<your resource group>",
+#'                     auth = interactive_auth)
+#' ```
+#' @seealso
+#' [get_workspace()] [service_principal_authentication()]
+#' @md
+interactive_login_authentication <- function(force = FALSE,
+                                             tenant_id = NULL,
+                                             cloud = "AzureCloud") {
+  azureml$core$authentication$InteractiveLoginAuthentication(
+    force = force, tenant_id = tenant_id, cloud = cloud)
+}
\ No newline at end of file
